<?php
/**
 * @file
 * A class to manage links
 */
class LinkApiLinkSet {

  /**
   * An array of \LinkApiLink's
   *
   * @var array
   */
  public $links;

  /**
   * Constructor
   */
  public function __construct() {
    module_load_include('inc', 'link_api', 'includes/LinkApiLink');
  }

  /**
   * Add a URL to this link set
   */
  public function addURL($url, $title = NULL, $nid = NULL) {
    $link = new LinkApiLink();
    $link->loadURL($url);

    if (isset($nid)) {
      $link->associateNode($nid);
    }
    if (isset($title)) {
      $link->title($title);
    }

    $this->links[] = $link;
  }

  /**
   * Add a new \LinkApiLink using its $lid
   */
  public function addLink($lid) {
    $link = new LinkApiLink();
    $link->read($lid);

    $this->links[] = $link;
  }

  /**
   * Save all links in the link set
   */
  public function save() {
    if (!empty($this->links)) {
      foreach ($this->links as $link) {

        /**
         * @var \LinkApiLink $link
         */
        $link->upsert();
      }
    }
  }

  /**
   * Find URLs
   *
   * @param string $key
   *  The key to search in
   * @param string $value
   *  The value to find in the key
   * @param string $realm [optional]
   *  A key for saving links against. Useful when you need to track links against
   *  several different fields in a node, but don't want to load or check them
   *  all every time. Defaults to LINK_API_REALM_ALL, though some functions, like
   *  link_api_update_node_links, will default to LINK_API_REALM_DEFAULT so as not to
   *  whack realm links inadvertently.
   */
  public function find($key, $value, $realm = LINK_API_REALM_ALL) {

    if (isset($realm) && $realm != LINK_API_REALM_ALL) {
      $query = "SELECT lid FROM {" . LINK_API_DB_NAME . "} WHERE `" . $key . "` = '%s' AND `realm` = %s";
      $result = db_query($query, $value, $realm);
    }
    else {
      $query = "SELECT lid FROM {" . LINK_API_DB_NAME . "} WHERE `" . $key . "` = '%s'";
      $result = db_query($query, $value);
    }


    while($item = db_fetch_array($result)) {
      $this->addLink($item['lid']);
    }
  }

  /**
   * Return all links in this object
   */
  public function links() {
    if (isset($this->links)) {
      return $this->links;
    }
    else {
      return array();
    }
  }
}
